@@ -11,12 +11,12 @@ class Singleton(type):
     """
 
     def __init__(self, *args, **kw):
-        super(Singleton, self).__init__(*args, **kw)
+        super().__init__(*args, **kw)
         self.__instance = None
 
     def __call__(self, *args, **kw):
         if self.__instance is None:
-            self.__instance = super(Singleton, self).__call__(*args, **kw)
+            self.__instance = super().__call__(*args, **kw)
         return self.__instance
 
 
@@ -28,13 +28,13 @@ class Cached(type):
     """
 
     def __init__(self, *args, **kw):
-        super(Singleton, self).__init__(*args, **kw)
+        super().__init__(*args, **kw)
         self.__cache = weakref.WeakValueDictionary()
 
     def __call__(self, *args):
         if args in self.__cache:
             return self.__cache[args]
 
-        obj = super(Singleton, self).__call__(*args)
+        obj = super().__call__(*args)
         self.__cache[args] = obj
         return obj
